﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Data;

namespace WpfXamMaskedEditBindingTest
{
	/// <summary>
	/// DataFilter used to allow the end user to edit period length using
	/// UltraMAskedEdit (hh:mm:ss) and store the result as seconds.
	/// </summary>
	public class XamDurationConverter : IValueConverter
	{
		private const char _timeSeparator = ':';

		/// <summary>
		/// Converts data between Display (user), Editor and Owner (data source).
		/// </summary>


		#region IValueConverter Members

		public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			string retVal = null;
			decimal? durationRaw = TypeConvertUtils.ToNullableDecimal(value);
			if( durationRaw.HasValue )
			{
				decimal duration = durationRaw.Value;
				// get the seconds that the owner has
				string hrs = "000";
				string mins = "00";
				string secs = "00";

				if( duration > 3599 )
				{
					decimal hours = Math.Floor(duration / 3600);
					hrs = hours.ToString("000");
					duration -= (3600 * hours);
				}
				if( duration > 59 )
				{
					decimal minutes = Math.Floor(duration / 60);
					mins = minutes.ToString("00");
					duration -= minutes * 60;
				}
				secs = duration.ToString("00");

				retVal = hrs + _timeSeparator + mins + _timeSeparator + secs;
			}

			retVal = retVal ?? "000:00:00";
			return retVal;
		}

		public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
		{
			object retVal = null;
			//DateTime value = System.Convert.ToDateTime(conversionArgs.Value);
			string text = TypeConvertUtils.ToString(value);
			if( !string.IsNullOrEmpty(text) )
			{
				string[] valarr = text.Split(_timeSeparator);

				decimal secs = 0;
				try
				{
					if( valarr.Length > 2 )
					{
						if( valarr[2].Length > 0 )
						{
							secs += decimal.Parse(valarr[2], System.Globalization.NumberStyles.Any);
						}
					}
					if( valarr.Length > 1 )
					{
						if( valarr[1].Length > 0 )
						{
							decimal mins = decimal.Parse(valarr[1], System.Globalization.NumberStyles.Any);
							if( mins > 0 )
							{
								secs += mins * 60;
							}
						}
					}
					if( valarr.Length > 0 )
					{
						if( valarr[0].Length > 0 )
						{
							decimal hrs = decimal.Parse(valarr[0], System.Globalization.NumberStyles.Any);
							if( hrs > 0 )
							{
								secs += hrs * 3600;
							}
						}
					}
				}
				catch( Exception )
				{
				}
				retVal = secs;
			}
			// return value as seconds
			return retVal;
		}

		#endregion
	}
}
